==> jc-1.4.0.tar.gz: soot/jimple/toolkits/annotation/arraycheck/IntContainer.h <==
// class soot.jimple.toolkits.annotation.arraycheck.IntContainer

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class fa23922817735cea soot_jimple_toolkits_annotation_arraycheck_IntContainer

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_jimple_toolkits_annotation_arraycheck_IntContainer_H_
#define _JC_soot_jimple_toolkits_annotation_arraycheck_IntContainer_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_jimple_toolkits_annotation_arraycheck_IntContainer$object;

// Typedefs
typedef struct _jc_soot_jimple_toolkits_annotation_arraycheck_IntContainer$sub_refs	_jc_soot_jimple_toolkits_annotation_arraycheck_IntContainer$sub_refs;
typedef struct _jc_soot_jimple_toolkits_annotation_arraycheck_IntContainer$sub_nonrefs	_jc_soot_jimple_toolkits_annotation_arraycheck_IntContainer$sub_nonrefs;
typedef struct _jc_soot_jimple_toolkits_annotation_arraycheck_IntContainer$refs	_jc_soot_jimple_toolkits_annotation_arraycheck_IntContainer$refs;
typedef struct _jc_soot_jimple_toolkits_annotation_arraycheck_IntContainer$nonrefs	_jc_soot_jimple_toolkits_annotation_arraycheck_IntContainer$nonrefs;
typedef struct _jc_soot_jimple_toolkits_annotation_arraycheck_IntContainer$object	_jc_soot_jimple_toolkits_annotation_arraycheck_IntContainer$object;

typedef struct _jc_soot_jimple_toolkits_annotation_arraycheck_IntContainer$fields_struct	_jc_soot_jimple_toolkits_annotation_arraycheck_IntContainer$fields_struct;
typedef const struct _jc_soot_jimple_toolkits_annotation_arraycheck_IntContainer$vmethods	_jc_soot_jimple_toolkits_annotation_arraycheck_IntContainer$vmethods;
typedef const struct _jc_soot_jimple_toolkits_annotation_arraycheck_IntContainer$vtable	_jc_soot_jimple_toolkits_annotation_arraycheck_IntContainer$vtable;
typedef const struct _jc_soot_jimple_toolkits_annotation_arraycheck_IntContainer$vtype	_jc_soot_jimple_toolkits_annotation_arraycheck_IntContainer$vtype;

// Class fields structure
struct _jc_soot_jimple_toolkits_annotation_arraycheck_IntContainer$fields_struct {
	_jc_object_array	*pool;
};
extern _jc_soot_jimple_toolkits_annotation_arraycheck_IntContainer$fields_struct _jc_soot_jimple_toolkits_annotation_arraycheck_IntContainer$class_fields;

// Constructors
extern void _jc_soot_jimple_toolkits_annotation_arraycheck_IntContainer$method$_init$7f1776288300b98d(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_IntContainer$object *, jint);

// Virtual methods
extern struct _jc_soot_jimple_toolkits_annotation_arraycheck_IntContainer$object *_jc_soot_jimple_toolkits_annotation_arraycheck_IntContainer$method$dup$ff145da413b9c1ca(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_IntContainer$object *);
extern jboolean _jc_soot_jimple_toolkits_annotation_arraycheck_IntContainer$method$equals$8a15e0625571c581(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_IntContainer$object *, struct _jc_java_lang_Object$object *);
extern jint _jc_soot_jimple_toolkits_annotation_arraycheck_IntContainer$method$hashCode$53152098849316df(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_IntContainer$object *);
extern struct _jc_java_lang_String$object *_jc_soot_jimple_toolkits_annotation_arraycheck_IntContainer$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_IntContainer$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_toolkits_annotation_arraycheck_IntContainer$method_info$dup$ff145da413b9c1ca;
extern _jc_method _jc_soot_jimple_toolkits_annotation_arraycheck_IntContainer$method_info$equals$8a15e0625571c581;
extern _jc_method _jc_soot_jimple_toolkits_annotation_arraycheck_IntContainer$method_info$hashCode$53152098849316df;
extern _jc_method _jc_soot_jimple_toolkits_annotation_arraycheck_IntContainer$method_info$toString$7ea43b33b80a3070;

// Static methods
extern void _jc_soot_jimple_toolkits_annotation_arraycheck_IntContainer$method$_clinit$a816641e0ba8bfef(_jc_env *);
extern struct _jc_soot_jimple_toolkits_annotation_arraycheck_IntContainer$object *_jc_soot_jimple_toolkits_annotation_arraycheck_IntContainer$method$v$d4c8a5bc14afcf4e(_jc_env *, jint);

// Virtual methods structure
struct _jc_soot_jimple_toolkits_annotation_arraycheck_IntContainer$vmethods {
	struct _jc_soot_jimple_toolkits_annotation_arraycheck_IntContainer$object	*(*dup$ff145da413b9c1ca)(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_IntContainer$object *);
	jboolean	(*equals$8a15e0625571c581)(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_IntContainer$object *, struct _jc_java_lang_Object$object *);
	jint	(*hashCode$53152098849316df)(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_IntContainer$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_IntContainer$object *);
};

// Vtable
struct _jc_soot_jimple_toolkits_annotation_arraycheck_IntContainer$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_toolkits_annotation_arraycheck_IntContainer$vmethods	soot_jimple_toolkits_annotation_arraycheck_IntContainer;
};

// Vtype
struct _jc_soot_jimple_toolkits_annotation_arraycheck_IntContainer$vtype {
	_jc_type			type;
	_jc_soot_jimple_toolkits_annotation_arraycheck_IntContainer$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_annotation_arraycheck_IntContainer$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_jimple_toolkits_annotation_arraycheck_IntContainer$refs {
    _jc_soot_jimple_toolkits_annotation_arraycheck_IntContainer$sub_refs	soot_jimple_toolkits_annotation_arraycheck_IntContainer;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_annotation_arraycheck_IntContainer$sub_nonrefs {
	jint	value;
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_toolkits_annotation_arraycheck_IntContainer$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_toolkits_annotation_arraycheck_IntContainer$sub_nonrefs	soot_jimple_toolkits_annotation_arraycheck_IntContainer;
};

// Object instance structure
struct _jc_soot_jimple_toolkits_annotation_arraycheck_IntContainer$object {
	_jc_soot_jimple_toolkits_annotation_arraycheck_IntContainer$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_toolkits_annotation_arraycheck_IntContainer$vtype	*vtype;
	_jc_soot_jimple_toolkits_annotation_arraycheck_IntContainer$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_toolkits_annotation_arraycheck_IntContainer$vtype _jc_soot_jimple_toolkits_annotation_arraycheck_IntContainer$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_toolkits_annotation_arraycheck_IntContainer, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_toolkits_annotation_arraycheck_IntContainer$class_object;

#endif	/* _JC_soot_jimple_toolkits_annotation_arraycheck_IntContainer_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/toolkits/annotation/arraycheck/IntContainer.h <==
// class soot.jimple.toolkits.annotation.arraycheck.IntContainer

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class fa23922817735cea soot_jimple_toolkits_annotation_arraycheck_IntContainer

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_jimple_toolkits_annotation_arraycheck_IntContainer_H_
#define _JC_soot_jimple_toolkits_annotation_arraycheck_IntContainer_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_jimple_toolkits_annotation_arraycheck_IntContainer$object;

// Typedefs
typedef struct _jc_soot_jimple_toolkits_annotation_arraycheck_IntContainer$sub_refs	_jc_soot_jimple_toolkits_annotation_arraycheck_IntContainer$sub_refs;
typedef struct _jc_soot_jimple_toolkits_annotation_arraycheck_IntContainer$sub_nonrefs	_jc_soot_jimple_toolkits_annotation_arraycheck_IntContainer$sub_nonrefs;
typedef struct _jc_soot_jimple_toolkits_annotation_arraycheck_IntContainer$refs	_jc_soot_jimple_toolkits_annotation_arraycheck_IntContainer$refs;
typedef struct _jc_soot_jimple_toolkits_annotation_arraycheck_IntContainer$nonrefs	_jc_soot_jimple_toolkits_annotation_arraycheck_IntContainer$nonrefs;
typedef struct _jc_soot_jimple_toolkits_annotation_arraycheck_IntContainer$object	_jc_soot_jimple_toolkits_annotation_arraycheck_IntContainer$object;

typedef struct _jc_soot_jimple_toolkits_annotation_arraycheck_IntContainer$fields_struct	_jc_soot_jimple_toolkits_annotation_arraycheck_IntContainer$fields_struct;
typedef const struct _jc_soot_jimple_toolkits_annotation_arraycheck_IntContainer$vmethods	_jc_soot_jimple_toolkits_annotation_arraycheck_IntContainer$vmethods;
typedef const struct _jc_soot_jimple_toolkits_annotation_arraycheck_IntContainer$vtable	_jc_soot_jimple_toolkits_annotation_arraycheck_IntContainer$vtable;
typedef const struct _jc_soot_jimple_toolkits_annotation_arraycheck_IntContainer$vtype	_jc_soot_jimple_toolkits_annotation_arraycheck_IntContainer$vtype;

// Class fields structure
struct _jc_soot_jimple_toolkits_annotation_arraycheck_IntContainer$fields_struct {
	_jc_object_array	*pool;
};
extern _jc_soot_jimple_toolkits_annotation_arraycheck_IntContainer$fields_struct _jc_soot_jimple_toolkits_annotation_arraycheck_IntContainer$class_fields;

// Constructors
extern void _jc_soot_jimple_toolkits_annotation_arraycheck_IntContainer$method$_init$7f1776288300b98d(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_IntContainer$object *, jint) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_soot_jimple_toolkits_annotation_arraycheck_IntContainer$object *_jc_soot_jimple_toolkits_annotation_arraycheck_IntContainer$method$dup$ff145da413b9c1ca(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_IntContainer$object *) _JC_JCNI_ATTR;
extern jboolean _jc_soot_jimple_toolkits_annotation_arraycheck_IntContainer$method$equals$8a15e0625571c581(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_IntContainer$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern jint _jc_soot_jimple_toolkits_annotation_arraycheck_IntContainer$method$hashCode$53152098849316df(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_IntContainer$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_jimple_toolkits_annotation_arraycheck_IntContainer$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_IntContainer$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_toolkits_annotation_arraycheck_IntContainer$method_info$dup$ff145da413b9c1ca;
extern _jc_method _jc_soot_jimple_toolkits_annotation_arraycheck_IntContainer$method_info$equals$8a15e0625571c581;
extern _jc_method _jc_soot_jimple_toolkits_annotation_arraycheck_IntContainer$method_info$hashCode$53152098849316df;
extern _jc_method _jc_soot_jimple_toolkits_annotation_arraycheck_IntContainer$method_info$toString$7ea43b33b80a3070;

// Static methods
extern void _jc_soot_jimple_toolkits_annotation_arraycheck_IntContainer$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;
extern struct _jc_soot_jimple_toolkits_annotation_arraycheck_IntContainer$object *_jc_soot_jimple_toolkits_annotation_arraycheck_IntContainer$method$v$d4c8a5bc14afcf4e(_jc_env *, jint) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_soot_jimple_toolkits_annotation_arraycheck_IntContainer$vmethods {
	struct _jc_soot_jimple_toolkits_annotation_arraycheck_IntContainer$object	*(*dup$ff145da413b9c1ca)(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_IntContainer$object *) _JC_JCNI_ATTR;
	jboolean	(*equals$8a15e0625571c581)(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_IntContainer$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	jint	(*hashCode$53152098849316df)(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_IntContainer$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_IntContainer$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_toolkits_annotation_arraycheck_IntContainer$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_toolkits_annotation_arraycheck_IntContainer$vmethods	soot_jimple_toolkits_annotation_arraycheck_IntContainer;
};

// Vtype
struct _jc_soot_jimple_toolkits_annotation_arraycheck_IntContainer$vtype {
	_jc_type			type;
	_jc_soot_jimple_toolkits_annotation_arraycheck_IntContainer$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_annotation_arraycheck_IntContainer$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_jimple_toolkits_annotation_arraycheck_IntContainer$refs {
    _jc_soot_jimple_toolkits_annotation_arraycheck_IntContainer$sub_refs	soot_jimple_toolkits_annotation_arraycheck_IntContainer;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_annotation_arraycheck_IntContainer$sub_nonrefs {
	jint	value;
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_toolkits_annotation_arraycheck_IntContainer$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_toolkits_annotation_arraycheck_IntContainer$sub_nonrefs	soot_jimple_toolkits_annotation_arraycheck_IntContainer;
};

// Object instance structure
struct _jc_soot_jimple_toolkits_annotation_arraycheck_IntContainer$object {
	_jc_soot_jimple_toolkits_annotation_arraycheck_IntContainer$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_toolkits_annotation_arraycheck_IntContainer$vtype	*vtype;
	_jc_soot_jimple_toolkits_annotation_arraycheck_IntContainer$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_toolkits_annotation_arraycheck_IntContainer$vtype _jc_soot_jimple_toolkits_annotation_arraycheck_IntContainer$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_toolkits_annotation_arraycheck_IntContainer, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_toolkits_annotation_arraycheck_IntContainer$class_object;

#endif	/* _JC_soot_jimple_toolkits_annotation_arraycheck_IntContainer_H_ */
